# Copyright 2013 John Reese
# Licensed under the MIT license

from __future__ import absolute_import

from .dotlink import Dotlink, VERSION
